plot.mlm_variance_decomp: Plot the variance decomposition of simple slopes

View source: R/mlm_variance_decomp.R

plot.mlm_variance_decompR Documentation

Plot the variance decomposition of simple slopes

Description

Shows the simple slope at each moderator value as a point with two interval layers: an inner confidence interval (fixed-effect uncertainty only) and an outer prediction interval (fixed + random-slope variance). The gap between the two intervals is the contribution of random-slope heterogeneity.

Usage

## S3 method for class 'mlm_variance_decomp'
plot(x, x_label = NULL, y_label = NULL, ...)

Arguments

x

An mlm_variance_decomp object.

x_label

x-axis label. Defaults to moderator name.

y_label

y-axis label. Defaults to "Simple slope of pred".

...

Ignored.

Value

A ggplot object.


mlmoderator documentation built on April 4, 2026, 1:07 a.m.