View source: R/mlm_variance_decomp.R
| plot.mlm_variance_decomp | R Documentation |
Shows the simple slope at each moderator value as a point with two interval layers: an inner confidence interval (fixed-effect uncertainty only) and an outer prediction interval (fixed + random-slope variance). The gap between the two intervals is the contribution of random-slope heterogeneity.
## S3 method for class 'mlm_variance_decomp'
plot(x, x_label = NULL, y_label = NULL, ...)
x |
An |
x_label |
x-axis label. Defaults to moderator name. |
y_label |
y-axis label. Defaults to "Simple slope of pred". |
... |
Ignored. |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.